@@ -14,7 +14,12 @@ from sys import stdout
 
 import mysql.connector
 import six
-from mysql.connector import CharacterSet, errorcode
+from mysql.connector import (
+    CharacterSet,
+    __version__ as mysql_connector_version_string,
+    errorcode,
+)
+from packaging import version
 from tqdm import tqdm, trange
 
 from sqlite3_to_mysql.sqlite_utils import (
@@ -26,7 +31,6 @@ from sqlite3_to_mysql.sqlite_utils import (
     convert_timedelta,
     unicase_compare,
 )
-
 from .mysql_utils import (
     MYSQL_BLOB_COLUMN_TYPES,
     MYSQL_COLUMN_TYPES,
@@ -49,6 +53,8 @@ class SQLite3toMySQL:
     COLUMN_PATTERN = re.compile(r"^[^(]+")
     COLUMN_LENGTH_PATTERN = re.compile(r"\(\d+\)$")
 
+    MYSQL_CONNECTOR_VERSION = version.parse(mysql_connector_version_string)
+
     def __init__(self, **kwargs):
         """Constructor."""
         if not kwargs.get("sqlite_file"):
@@ -243,7 +249,7 @@ class SQLite3toMySQL:
             self._mysql_cur.close()
             self._mysql.commit()
             self._mysql.database = self._mysql_database
-            self._mysql_cur = self._mysql.cursor(prepared=True)
+            self._mysql_cur = self._mysql.cursor(prepared=True)  # pylint: disable=W0201
         except mysql.connector.Error as err:
             self._logger.error(
                 "MySQL failed creating databse %s: %s",
